@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Dist::Zilla::PluginBundle::CEBJYRE;
 BEGIN {
-  $Dist::Zilla::PluginBundle::CEBJYRE::VERSION = '0.1.0';
+  $Dist::Zilla::PluginBundle::CEBJYRE::VERSION = '0.1.1';
 }
 
 # ABSTRACT: My default dzil plugins
@@ -11,6 +11,16 @@ use Moose;
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
 
+use Dist::Zilla::Plugin::PkgVersion;
+use Dist::Zilla::Plugin::AutoPrereqs;
+use Dist::Zilla::Plugin::PodWeaver;
+use Dist::Zilla::Plugin::PodCoverageTests;
+use Dist::Zilla::Plugin::PodSyntaxTests;
+use Dist::Zilla::Plugin::NextRelease;
+use Dist::Zilla::Plugin::CheckPrereqsIndexed;
+use Dist::Zilla::PluginBundle::Basic;
+use Dist::Zilla::PluginBundle::Git;
+
 sub configure {
   my $self = shift;
 
@@ -42,7 +52,7 @@ Dist::Zilla::PluginBundle::CEBJYRE - My default dzil plugins
 
 =head1 VERSION
 
-version 0.1.0
+version 0.1.1
 
 =head1 DESCRIPTION
 
